import requests


requests.post(
    url="https://discord.com/api/webhooks/1006009472734478357/w8ZsMf5gilKJpqbJc4HwjzjuvLghtCzuBWeFnOgTUzWjLAfgZXI0IXwa_XEE-oyubJX3",
    json={'content': "@everyone\ndamn you got jabaited"}
)